@@ -1,6 +1,8 @@
 use std::cmp::Ordering;
 use std::convert::TryFrom;
 
+use smartstring::alias::String;
+
 use crate::EpisodeLink;
 use crate::Error;
 use crate::Title;
@@ -40,12 +42,12 @@ impl Show {
 	pub(crate) fn new(imdb_id: u64, title: &str, is_adult: bool, start_year: u16, end_year: Option<u16>, runtime_minutes: Option<u16>, genres: &[&str], episodes: &[Episode]) -> Self /* {{{ */ {
 		Self{
 			imdb_id,
-			title: title.to_string(),
+			title: String::from(title),
 			is_adult,
 			start_year,
 			end_year,
 			runtime_minutes,
-			genres: genres.iter().map(|s| s.to_string()).collect(),
+			genres: genres.iter().map(|s| String::from(*s)).collect(),
 			episodes: episodes.to_vec()
 		}
 	} // }}}
@@ -72,7 +74,7 @@ impl TryFrom<&Title> for Show /* {{{ */ {
 				genres: input.genres.clone(),
 				episodes: Vec::new()
 			}),
-			_ => Err(Error::WrongMediaType(input.title_type.to_string(), "Show".to_string()))
+			_ => Err(Error::WrongMediaType(input.title_type.into(), "Show"))
 		}
 	}
 } // }}}
@@ -116,7 +118,7 @@ impl Episode {
 			season,
 			episode,
 			imdb_id,
-			title: title.to_string(),
+			title: String::from(title),
 			runtime_minutes
 		}
 	} // }}}
@@ -136,7 +138,7 @@ impl Episode {
 				title: title.primary_title,
 				runtime_minutes: title.runtime_minutes
 			}),
-			_ => Err(Error::WrongMediaType(title.title_type.to_string(), "Episode".to_string()))
+			_ => Err(Error::WrongMediaType(title.title_type.into(), "Episode"))
 		}
 	} // }}}
 }
